EXPORTS
	??0CPBAuthData@@IAE@XZ @ 1 NONAME ; CPBAuthData::CPBAuthData(void)
	??0CPBEncryptParms@@IAE@XZ @ 2 NONAME ; CPBEncryptParms::CPBEncryptParms(void)
	??0CPBEncryptionData@@IAE@XZ @ 3 NONAME ; CPBEncryptionData::CPBEncryptionData(void)
	??0TPBPassword@@QAE@ABVTDesC16@@@Z @ 4 NONAME ; TPBPassword::TPBPassword(class TDesC16 const &)
	??0TPBPassword@@QAE@ABVTDesC8@@@Z @ 5 NONAME ; TPBPassword::TPBPassword(class TDesC8 const &)
	??8CPBAuthData@@QBEHABV0@@Z @ 6 NONAME ; int CPBAuthData::operator==(class CPBAuthData const &) const
	?AuthData@CPBEncryptionData@@QBEABVCPBAuthData@@XZ @ 7 NONAME ; class CPBAuthData const & CPBEncryptionData::AuthData(void) const
	?ChangePasswordL@CPBEncryptSet@@QAEXABVTPBPassword@@@Z @ 8 NONAME ; void CPBEncryptSet::ChangePasswordL(class TPBPassword const &)
	?Cipher@CPBEncryptParms@@QBE?AW4TPBECipher@@XZ @ 9 NONAME ; enum TPBECipher CPBEncryptParms::Cipher(void) const
	?DeriveKeyL@TPKCS5KDF@@SAXAAVTDes8@@ABVTDesC8@@1I@Z @ 10 NONAME ; void TPKCS5KDF::DeriveKeyL(class TDes8 &, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?EncryptParms@CPBEncryptionData@@QBEABVCPBEncryptParms@@XZ @ 11 NONAME ; class CPBEncryptParms const & CPBEncryptionData::EncryptParms(void) const
	?EncryptedMasterKey@CPBEncryptSet@@QBEABVTDesC8@@XZ @ 12 NONAME ; class TDesC8 const & CPBEncryptSet::EncryptedMasterKey(void) const
	?IV@CPBEncryptParms@@QBE?AVTPtrC8@@XZ @ 13 NONAME ; class TPtrC8 CPBEncryptParms::IV(void) const
	?Iterations@CPBAuthData@@QBEHXZ @ 14 NONAME ; int CPBAuthData::Iterations(void) const
	?Iterations@CPBEncryptParms@@QBEHXZ @ 15 NONAME ; int CPBEncryptParms::Iterations(void) const
	?Key@CPBAuthData@@QBE?AVTPtrC8@@XZ @ 16 NONAME ; class TPtrC8 CPBAuthData::Key(void) const
	?NewL@CPBAuthData@@SAPAV1@ABV1@@Z @ 17 NONAME ; class CPBAuthData * CPBAuthData::NewL(class CPBAuthData const &)
	?NewL@CPBAuthData@@SAPAV1@ABVTDesC8@@0II@Z @ 18 NONAME ; class CPBAuthData * CPBAuthData::NewL(class TDesC8 const &, class TDesC8 const &, unsigned int, unsigned int)
	?NewL@CPBDecryptorElement@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1@Z @ 19 NONAME ; class CPBDecryptorElement * CPBDecryptorElement::NewL(enum TPBECipher, class TDesC8 const &, class TDesC8 const &)
	?NewL@CPBDecryptorSet@@SAPAV1@W4TPBECipher@@ABVTDesC8@@@Z @ 20 NONAME ; class CPBDecryptorSet * CPBDecryptorSet::NewL(enum TPBECipher, class TDesC8 const &)
	?NewL@CPBEncryptElement@@SAPAV1@ABVCPBEncryptionData@@ABVTPBPassword@@@Z @ 21 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewL(class CPBEncryptionData const &, class TPBPassword const &)
	?NewL@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@@Z @ 22 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewL(class TPBPassword const &)
	?NewL@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@ABVCPBEncryptParms@@@Z @ 23 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewL(class TPBPassword const &, class CPBEncryptParms const &)
	?NewL@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@W4TPBECipher@@@Z @ 24 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewL(class TPBPassword const &, enum TPBECipher)
	?NewL@CPBEncryptParms@@SAPAV1@ABV1@@Z @ 25 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewL(class CPBEncryptParms const &)
	?NewL@CPBEncryptParms@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1I@Z @ 26 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewL(enum TPBECipher, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?NewL@CPBEncryptSet@@SAPAV1@ABVCPBEncryptionData@@ABVTDesC8@@ABVTPBPassword@@@Z @ 27 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewL(class CPBEncryptionData const &, class TDesC8 const &, class TPBPassword const &)
	?NewL@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@@Z @ 28 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewL(class TPBPassword const &)
	?NewL@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@ABVCPBEncryptParms@@@Z @ 29 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewL(class TPBPassword const &, class CPBEncryptParms const &)
	?NewL@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@W4TPBECipher@@@Z @ 30 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewL(class TPBPassword const &, enum TPBECipher)
	?NewL@CPBEncryptionData@@SAPAV1@ABV1@@Z @ 31 NONAME ; class CPBEncryptionData * CPBEncryptionData::NewL(class CPBEncryptionData const &)
	?NewL@CPBEncryptionData@@SAPAV1@ABVTDesC8@@W4TPBECipher@@000I@Z @ 32 NONAME ; class CPBEncryptionData * CPBEncryptionData::NewL(class TDesC8 const &, enum TPBECipher, class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?NewL@CPBEncryptorElement@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1@Z @ 33 NONAME ; class CPBEncryptorElement * CPBEncryptorElement::NewL(enum TPBECipher, class TDesC8 const &, class TDesC8 const &)
	?NewL@CPBEncryptorSet@@SAPAV1@W4TPBECipher@@ABVTDesC8@@@Z @ 34 NONAME ; class CPBEncryptorSet * CPBEncryptorSet::NewL(enum TPBECipher, class TDesC8 const &)
	?NewLC@CPBAuthData@@SAPAV1@ABV1@@Z @ 35 NONAME ; class CPBAuthData * CPBAuthData::NewLC(class CPBAuthData const &)
	?NewLC@CPBAuthData@@SAPAV1@ABVTDesC8@@0II@Z @ 36 NONAME ; class CPBAuthData * CPBAuthData::NewLC(class TDesC8 const &, class TDesC8 const &, unsigned int, unsigned int)
	?NewLC@CPBDecryptorElement@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1@Z @ 37 NONAME ; class CPBDecryptorElement * CPBDecryptorElement::NewLC(enum TPBECipher, class TDesC8 const &, class TDesC8 const &)
	?NewLC@CPBDecryptorSet@@SAPAV1@W4TPBECipher@@ABVTDesC8@@@Z @ 38 NONAME ; class CPBDecryptorSet * CPBDecryptorSet::NewLC(enum TPBECipher, class TDesC8 const &)
	?NewLC@CPBEncryptElement@@SAPAV1@ABVCPBEncryptionData@@ABVTPBPassword@@@Z @ 39 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewLC(class CPBEncryptionData const &, class TPBPassword const &)
	?NewLC@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@@Z @ 40 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewLC(class TPBPassword const &)
	?NewLC@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@ABVCPBEncryptParms@@@Z @ 41 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewLC(class TPBPassword const &, class CPBEncryptParms const &)
	?NewLC@CPBEncryptElement@@SAPAV1@ABVTPBPassword@@W4TPBECipher@@@Z @ 42 NONAME ; class CPBEncryptElement * CPBEncryptElement::NewLC(class TPBPassword const &, enum TPBECipher)
	?NewLC@CPBEncryptParms@@SAPAV1@ABV1@@Z @ 43 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewLC(class CPBEncryptParms const &)
	?NewLC@CPBEncryptParms@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1I@Z @ 44 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewLC(enum TPBECipher, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?NewLC@CPBEncryptSet@@SAPAV1@ABVCPBEncryptionData@@ABVTDesC8@@ABVTPBPassword@@@Z @ 45 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewLC(class CPBEncryptionData const &, class TDesC8 const &, class TPBPassword const &)
	?NewLC@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@@Z @ 46 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewLC(class TPBPassword const &)
	?NewLC@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@ABVCPBEncryptParms@@@Z @ 47 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewLC(class TPBPassword const &, class CPBEncryptParms const &)
	?NewLC@CPBEncryptSet@@SAPAV1@ABVTPBPassword@@W4TPBECipher@@@Z @ 48 NONAME ; class CPBEncryptSet * CPBEncryptSet::NewLC(class TPBPassword const &, enum TPBECipher)
	?NewLC@CPBEncryptionData@@SAPAV1@ABV1@@Z @ 49 NONAME ; class CPBEncryptionData * CPBEncryptionData::NewLC(class CPBEncryptionData const &)
	?NewLC@CPBEncryptionData@@SAPAV1@ABVTDesC8@@W4TPBECipher@@000I@Z @ 50 NONAME ; class CPBEncryptionData * CPBEncryptionData::NewLC(class TDesC8 const &, enum TPBECipher, class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?NewLC@CPBEncryptorElement@@SAPAV1@W4TPBECipher@@ABVTDesC8@@1@Z @ 51 NONAME ; class CPBEncryptorElement * CPBEncryptorElement::NewLC(enum TPBECipher, class TDesC8 const &, class TDesC8 const &)
	?NewLC@CPBEncryptorSet@@SAPAV1@W4TPBECipher@@ABVTDesC8@@@Z @ 52 NONAME ; class CPBEncryptorSet * CPBEncryptorSet::NewLC(enum TPBECipher, class TDesC8 const &)
	?Password@TPBPassword@@QBEABVTDesC8@@XZ @ 53 NONAME ; class TDesC8 const & TPBPassword::Password(void) const
	?Salt@CPBAuthData@@QBE?AVTPtrC8@@XZ @ 54 NONAME ; class TPtrC8 CPBAuthData::Salt(void) const
	?Salt@CPBEncryptParms@@QBE?AVTPtrC8@@XZ @ 55 NONAME ; class TPtrC8 CPBEncryptParms::Salt(void) const
	?DeriveKeyL@PKCS12KDF@@SAXAAVTDes8@@W4TIDByteType@1@ABVTDesC8@@2I@Z @ 56 NONAME ; void PKCS12KDF::DeriveKeyL(class TDes8 &, enum PKCS12KDF::TIDByteType, class TDesC8 const &, class TDesC8 const &, unsigned int)
	?GeneratePasswordLC@PKCS12KDF@@SAPAVHBufC8@@ABVTDesC16@@@Z @ 57 NONAME ; class HBufC8 * PKCS12KDF::GeneratePasswordLC(class TDesC16 const &)
	?Kdf@CPBEncryptParms@@QBE?AW4TKdf@1@XZ @ 58 NONAME ; enum CPBEncryptParms::TKdf CPBEncryptParms::Kdf(void) const
	?NewL@CPBEncryptParms@@SAPAV1@XZ @ 59 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewL(void)
	?NewL@CPBEncryptionData@@SAPAV1@ABVTDesC8@@0ABVCPBEncryptParms@@@Z @ 60 NONAME ; class CPBEncryptionData * CPBEncryptionData::NewL(class TDesC8 const &, class TDesC8 const &, class CPBEncryptParms const &)
	?NewLC@CPBEncryptParms@@SAPAV1@XZ @ 61 NONAME ; class CPBEncryptParms * CPBEncryptParms::NewLC(void)
	?ResizeSaltL@CPBEncryptParms@@QAEXH@Z @ 62 NONAME ; void CPBEncryptParms::ResizeSaltL(int)
	?SetCipher@CPBEncryptParms@@QAEXW4TPBECipher@@@Z @ 63 NONAME ; void CPBEncryptParms::SetCipher(enum TPBECipher)
	?SetIV@CPBEncryptParms@@QAEXABVTDesC8@@@Z @ 64 NONAME ; void CPBEncryptParms::SetIV(class TDesC8 const &)
	?SetIterations@CPBEncryptParms@@QAEXH@Z @ 65 NONAME ; void CPBEncryptParms::SetIterations(int)
	?SetKdf@CPBEncryptParms@@QAEXW4TKdf@1@@Z @ 66 NONAME ; void CPBEncryptParms::SetKdf(enum CPBEncryptParms::TKdf)

